@@ -5,7 +5,6 @@ Author: Nikolay Lysenko
 """
 
 
-from . import utils
 from .load_presets import create_timbres_registry
 from .midi_to_numpy import convert_midi_to_timeline
 from .numpy_to_wav import write_timeline_to_wav
@@ -14,5 +13,5 @@ from .tsv_to_numpy import convert_tsv_to_timeline
 
 __all__ = [
     'convert_midi_to_timeline', 'convert_tsv_to_timeline',
-    'create_timbres_registry', 'utils', 'write_timeline_to_wav'
+    'create_timbres_registry', 'write_timeline_to_wav'
 ]
